using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MindFusion.Scheduling;
using MindFusion.Scheduling.WinForms;

namespace ResourceViewCustomDraw
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			calendar1.CustomizeGrouping += new EventHandler<CustomizeGroupingEventArgs>(calendar1_CustomizeGrouping);

			//Resource a = new MachineA(); a.Name = "a1";
			//calendar1.Resources.Add(a);
			//a = new MachineA(); a.Name = "a2";
			//calendar1.Resources.Add(a);
			//a = new MachineA(); a.Name = "a3";
			//calendar1.Resources.Add(a);
			//a = new MachineB(); a.Name = "b1";
			//calendar1.Resources.Add(a);
			//a = new MachineB(); a.Name = "b2";
			//calendar1.Resources.Add(a);

			for (int i = 0; i < 20; i++)
			{
				MachineA a = new MachineA(); a.Name = string.Format("a{0}", i);
				calendar1.Resources.Add(a);
			}
			for (int i = 0; i < 50; i++)
			{
				MachineB b = new MachineB(); b.Name = string.Format("b{0}", i);
				calendar1.Resources.Add(b);
			}

			calendar1.GroupType = MindFusion.Scheduling.WinForms.GroupType.GroupByResources;
			calendar1.SecondaryGroupType = MindFusion.Scheduling.WinForms.GroupType.GroupByResources;
			calendar1.CustomGroupType = typeof(MachineA);
			calendar1.CustomSecondaryGroupType = typeof(MachineB);

			calendar1.ItemModified += new EventHandler<MindFusion.Scheduling.WinForms.ItemModifiedEventArgs>(calendar1_ItemModified);

			calendar1.MouseDown += new MouseEventHandler(calendar1_MouseDown);
			calendar1.ShowToolTips = true;

			calendar1.ItemCreated += new EventHandler<ItemEventArgs>(calendar1_ItemCreated);
		}

		void calendar1_CustomizeGrouping(object sender, CustomizeGroupingEventArgs e)
		{
			if (e.Parents.Length == 1)
			{
				string n = e.Parents[0].Name.Substring(1);
				for (int i = 0; i < e.GroupByResources.Count; )
				{
					if (!e.GroupByResources[i].Name.Contains(n))
						e.GroupByResources.RemoveAt(i);
					else
						i++;
				}
			}
		}

		void calendar1_ItemCreated(object sender, ItemEventArgs e)
		{
			if (calendar1.Schedule.Items.Count == 1)
			{
				e.Item.Priority = 10;
				e.Item.HeaderText = "World";
			}
			else
			{
				e.Item.Priority = 0;
				e.Item.HeaderText = "Hello";
			}
		}

		void calendar1_MouseDown(object sender, MouseEventArgs e)
		{
			Calendar calendar = calendar1;
			//calendar1.GetElementBounds(MindFusion.Scheduling.WinForms.CalendarElement.ResourceViewHeader, 0);
			Resource resource = calendar.GetResourceAt(e.X, e.Y);
			if (resource != null)
			{
				if (calendar.GetDateAt(e.X, e.Y) == DateTime.MinValue)
					MessageBox.Show(resource.Name);
			}
		}

		void calendar1_ItemModified(object sender, MindFusion.Scheduling.WinForms.ItemModifiedEventArgs e)
		{
		}

		class MachineA : Resource
		{
		}

		class MachineB : Resource
		{
		}

		private void calendar1_Draw(object sender, MindFusion.Scheduling.WinForms.DrawEventArgs e)
		{
			Rectangle bounds = e.Bounds;
			bounds.Inflate(-1, -1);
			bounds.Width += 1;
			bounds.Height += 1;

			if (e.Element == MindFusion.Scheduling.WinForms.CustomDrawElements.ItemMoveBand)
			{
				SolidBrush brush = new SolidBrush(Color.FromArgb(0x77, 0xDD, 0x23));

				Rectangle infoRect = bounds;
				infoRect.X = bounds.X;
				infoRect.Width = (int)(bounds.Width * 0.3f);
				e.Graphics.FillRectangle(brush, infoRect);

				infoRect.X = bounds.X + (int)(bounds.Width * 0.45f);
				infoRect.Width = (int)(bounds.Width * 0.1f);
				e.Graphics.FillRectangle(brush, infoRect);

				infoRect.X = bounds.X + (int)(bounds.Width * 0.6f);
				infoRect.Width = (int)Math.Ceiling(bounds.Width * 0.4f);
				e.Graphics.FillRectangle(brush, infoRect);

				brush.Dispose();
			}
			else if (e.Element == MindFusion.Scheduling.WinForms.CustomDrawElements.ResourceViewItem)
			{
				DateTime from = calendar1.GetDateAt(e.Bounds.Left + (int)e.Graphics.Transform.OffsetX, e.Bounds.Top);
				DateTime to = calendar1.GetDateAt(e.Bounds.Right + (int)e.Graphics.Transform.OffsetX, e.Bounds.Top);
				DateTime mark = e.Item.StartTime.AddDays(2);
				if (from <= mark && mark <= to)
				{
					int distance = (int)(bounds.Width * ((double)mark.Ticks - from.Ticks) / (to.Ticks - from.Ticks));
					e.Graphics.DrawLine(Pens.Red, bounds.Left + distance, bounds.Top, bounds.Left + distance, bounds.Bottom);
				}
			}
		}

		private void button1_Click(object sender, EventArgs e)
		{
			if (calendar1.ItemSelection.Items.Length == 0)
				return;

			calendar1.EnsureVisible(calendar1.ItemSelection.Items[0]);
		}

		private void button2_Click(object sender, EventArgs e)
		{
			calendar1.EnsureVisible(DateTime.Now);
		}
	}
}